"use client";

import React, { useState } from 'react';
import Head from 'next/head';
import { FaList, FaTelegramPlane, FaInfoCircle } from 'react-icons/fa';
import { MdOutlinePrivacyTip } from 'react-icons/md';

export default function MorePage() {
  const [isDisclaimerOpen, setIsDisclaimerOpen] = useState(false);
  const [isAboutOpen, setIsAboutOpen] = useState(false);

  const handleCopyLink = () => {
    navigator.clipboard.writeText('https://www.delgor.com'); // Replace with your actual URL
    alert('Link copied to clipboard!');
  };

  return (
    <>
      <Head>
        <title>More - Delgor Settings</title>
        <meta
          name="description"
          content="Explore more options including My List, Telegram communities, and learn about Delgor."
        />
      </Head>
      <div className="flex flex-col items-center justify-start min-h-screen bg-black text-white p-6 md:pt-20"> {/* Add padding top on larger screens */}
        <div className="w-full md:max-w-4xl space-y-8"> {/* Adjust max width for PC screens */}
          {/* Tell a Friend Section */}
          <div className="p-4 bg-gray-800 rounded-lg space-y-4">
            <h2 className="text-xl font-bold text-white">
              Tell your friends
            </h2>
            <p className="text-sm text-gray-300">
              Spread this link to your friends so they can enjoy free streams and downloads.
            </p>
            <div className="flex items-center space-x-2">
              <span className="flex-grow bg-gray-900 p-2 rounded text-sm">https://www.delgor.com</span> {/* Replace with your actual URL */}
              <button
                onClick={handleCopyLink}
                className="px-4 py-2 bg-red-600 hover:bg-red-700 text-white font-semibold rounded-lg transition duration-300 ease-in-out"
              >
                Copy
              </button>
            </div>
          </div>

          {/* Options List */}
          <div className="w-full bg-gray-800 rounded-lg">
            <a href="/mylist" className="flex items-center p-4 hover:bg-gray-700 border-b border-gray-700">
              <FaList className="text-white mr-4" />
              My List
            </a>

            <a href="https://t.me/delgormovies" target="_blank" rel="noopener noreferrer" className="flex items-center p-4 hover:bg-gray-700 border-b border-gray-700">
              <FaTelegramPlane className="text-white mr-4" />
              Join Telegram Channel
            </a>

            <a href="https://t.me/delgomoviesdiscussion" target="_blank" rel="noopener noreferrer" className="flex items-center p-4 hover:bg-gray-700 border-b border-gray-700">
              <FaTelegramPlane className="text-white mr-4" />
              Join Telegram Community
            </a>

            <button
              onClick={() => setIsDisclaimerOpen(true)}
              className="flex items-center w-full p-4 hover:bg-gray-700 border-b border-gray-700 text-left"
            >
              <MdOutlinePrivacyTip className="text-white mr-4" />
              Disclaimer
            </button>

            <button
              onClick={() => setIsAboutOpen(true)}
              className="flex items-center w-full p-4 hover:bg-gray-700 text-left"
            >
              <FaInfoCircle className="text-white mr-4" />
              About Us
            </button>
          </div>
        </div>
      </div>

      {/* Disclaimer Popup */}
      {isDisclaimerOpen && (
        <div className="fixed inset-0 bg-black bg-opacity-75 flex items-center justify-center z-50">
          <div className="bg-gray-800 p-6 rounded-lg text-center max-w-sm">
            <h3 className="text-xl font-bold text-red-500 mb-4">Disclaimer</h3>
            <p className="mb-4">
              Delgor does not store any files on our server; we only link to the media hosted on 3rd party services.
            </p>
            <button
              onClick={() => setIsDisclaimerOpen(false)}
              className="px-4 py-2 bg-red-600 hover:bg-red-700 text-white font-semibold rounded-lg transition duration-300 ease-in-out"
            >
              Close
            </button>
          </div>
        </div>
      )}

      {/* About Us Popup */}
      {isAboutOpen && (
        <div className="fixed inset-0 bg-black bg-opacity-75 flex items-center justify-center z-50">
          <div className="bg-gray-800 p-6 rounded-lg text-center max-w-sm">
            <h3 className="text-xl font-bold text-red-500 mb-4">About Us</h3>
            <p className="mb-4">
              Delgor is your ultimate platform for streaming movies, TV shows, and more with a futuristic design and smooth experience.
            </p>
            <button
              onClick={() => setIsAboutOpen(false)}
              className="px-4 py-2 bg-red-600 hover:bg-red-700 text-white font-semibold rounded-lg transition duration-300 ease-in-out"
            >
              Close
            </button>
          </div>
        </div>
      )}
    </>
  );
}
